==> foundation-1.0.2.tgz: package/src/Unique.ts <==

let uniqueStringCalls = 0

export default class Unique {

    static string(): string {
        uniqueStringCalls += 1;
        const timestamp: number = Date.now();
        const random: number = Math.random() * Math.pow(10, 17);
        return `${uniqueStringCalls}-${timestamp}-${random.toString(16)}`;
    }

    static numberInRange(min: number, max: number): number {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }
    
    static shortestString(existingStrings: string[]): string {
        const charSet: string = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
        function incrementString(str: string): string {
            let carry = true;
            let result = "";
            for (let i = str.length - 1; i >= 0 && carry; i--) {
                const index = charSet.indexOf(str[i]);
                const newIndex = (index + 1) % charSet.length;
                carry = newIndex === 0;
                result = charSet[newIndex] + result;
            }
            if (carry) {
                result = charSet[0] + result;
            }
            return result;
        }
        let newString = charSet[0];
        while (existingStrings.includes(newString)) {
            newString = incrementString(newString);
        }
        return newString;
    }


    static shortestNumber(existingNumbers: number[]): number {
        let newNumber = 0;
        while (existingNumbers.includes(newNumber)) {
            newNumber++;
        }
        return newNumber;
    }


}

==> foundation-1.0.9.tgz: package/src/Unique.ts <==

let uniqueStringCalls = 0

export default class Unique {

    static string(): string {
        uniqueStringCalls += 1;
        const timestamp: number = Date.now();
        const array = new Uint32Array(5); 
        crypto.getRandomValues(array);
        const randomNumbers = Array.from(array).join('');
        return `${uniqueStringCalls}-${timestamp}-${randomNumbers}`;
    }

    static numberInRange(min: number, max: number): number {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }
    
    static shortestString(existingStrings: string[]): string {
        const charSet: string = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
        function incrementString(str: string): string {
            let carry = true;
            let result = "";
            for (let i = str.length - 1; i >= 0 && carry; i--) {
                const index = charSet.indexOf(str[i]);
                const newIndex = (index + 1) % charSet.length;
                carry = newIndex === 0;
                result = charSet[newIndex] + result;
            }
            if (carry) {
                result = charSet[0] + result;
            }
            return result;
        }
        let newString = charSet[0];
        while (existingStrings.includes(newString)) {
            newString = incrementString(newString);
        }
        return newString;
    }


    static shortestNumber(existingNumbers: number[]): number {
        let newNumber = 0;
        while (existingNumbers.includes(newNumber)) {
            newNumber++;
        }
        return newNumber;
    }


}
